Examples and Tutorials
======================

You can find here detailed examples for different parts of plaid, explained mainly in jupyter notebooks.

.. note::
   The `Muscat=2.5.1 <https://anaconda.org/conda-forge/muscat>`_ dependency is required on some of the notebooks,
   and is not distributed with the `plaid <https://anaconda.org/conda-forge/plaid>`_
   conda-forge package.



.. toctree::
   :glob:
   :maxdepth: 1

   notebooks/containers/sample_example
   notebooks/containers/dataset_example
   notebooks/problem_definition_example
   notebooks/utils/split_example
   notebooks/utils/stats_example
   notebooks/post/bisect_example
   notebooks/post/metrics_example
   notebooks/utils/init_with_tabular_example
   notebooks/utils/interpolation_example
   notebooks/bridges/huggingface_example
   notebooks/pipelines/pipeline_example
   notebooks/examples/downloadable_example
   tutorials/storage